@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,16 +21,22 @@ class AKONADI_SEARCH_DEBUG_EXPORT AkonadiSearchDebugSearchPathComboBox : public
     Q_OBJECT
 public:
     explicit AkonadiSearchDebugSearchPathComboBox(QWidget *parent = nullptr);
-    enum SearchType { Contacts = 0, ContactCompleter, Emails, Notes, Calendars };
+    enum SearchType {
+        Contacts = 0,
+        ContactCompleter,
+        Emails,
+        Notes,
+        Calendars,
+    };
     ~AkonadiSearchDebugSearchPathComboBox() override;
 
-    QString searchPath();
+    Q_REQUIRED_RESULT QString searchPath() const;
 
-    QString pathFromEnum(SearchType type);
+    Q_REQUIRED_RESULT QString pathFromEnum(SearchType type) const;
     void setSearchType(SearchType type);
 
 private:
-    QString defaultLocations(const QString &dbname);
+    const QString defaultLocations(const QString &dbname) const;
     void initialize();
 };
 }
